RestoreManager

Struct RestoreManager 

pub struct RestoreManager { /* private fields */ }
Handles restoring from backups

Implementations

Source

impl RestoreManager

pub fn new(paths: EnvelopePaths) -> Self

Create a new RestoreManager

pub fn restore_from_file( &self, backup_path: &Path, ) -> EnvelopeResult<RestoreResult>

Restore data from a backup file

This will overwrite all current data with the backup contents. It’s recommended to create a backup before restoring. Supports both internal backup format and export format files. Supports both JSON and YAML formats (detected by file extension).

pub fn restore_from_archive( &self, archive: &BackupArchive, ) -> EnvelopeResult<RestoreResult>

Restore data from a parsed backup archive (internal format)

pub fn validate_backup( &self, backup_path: &Path, ) -> EnvelopeResult<ValidationResult>

Validate a backup file without restoring it Supports both internal backup format and export format files. Supports both JSON and YAML formats (detected by file extension).