pub fn get_encryption_key(
settings: &Settings,
passphrase: &str,
) -> EnvelopeResult<DerivedKey>Expand description
Get the derived key from a passphrase and settings
pub fn get_encryption_key(
settings: &Settings,
passphrase: &str,
) -> EnvelopeResult<DerivedKey>Get the derived key from a passphrase and settings