Module encryption

Module encryption 

AES-256-GCM encryption/decryption

Provides authenticated encryption for data at rest using AES-256-GCM. Each encryption operation generates a unique nonce for security.

Structs

EncryptedData
Encrypted data with associated metadata

Functions

decrypt
Decrypt ciphertext using AES-256-GCM
decrypt_string
Decrypt to a string
encrypt
Encrypt plaintext data using AES-256-GCM
encrypt_string
Encrypt a string