Secure memory handling for sensitive data
Provides types that securely zero memory on drop to prevent sensitive data from lingering in memory.
Structs
- Secure
Bytes - A byte vector that zeros its contents on drop
- Secure
String - A string type that zeros its contents on drop