Module account

Module account 

Account display formatting

Formats accounts for terminal output in table and detail views.

Functions

format_account_details
Format a single account’s details
format_account_list
Format a list of accounts with balances as a table
format_account_list_simple
Format a simple account list (name and type only)