Module category

Module category 

Category display formatting

Formats categories and groups for terminal output in tree and table views.

Functions

format_category_details
Format category details
format_category_list
Format a simple list of categories
format_category_tree
Format categories as a tree structure grouped by category group
format_group_details
Format group details
format_group_list
Format a simple list of groups