pub fn restore_from_export(
storage: &Storage,
export: &FullExport,
) -> EnvelopeResult<ExportRestoreResult>Expand description
Restore data from a FullExport to storage
This will overwrite all existing data with the export contents.
pub fn restore_from_export(
storage: &Storage,
export: &FullExport,
) -> EnvelopeResult<ExportRestoreResult>Restore data from a FullExport to storage
This will overwrite all existing data with the export contents.