CategoryService

Struct CategoryService 

pub struct CategoryService<'a> { /* private fields */ }
Service for category management

Implementations

Source

impl<'a> CategoryService<'a>

pub fn new(storage: &'a Storage) -> Self

Create a new category service

pub fn create_group(&self, name: &str) -> EnvelopeResult<CategoryGroup>

Create a new category group

pub fn get_group( &self, id: CategoryGroupId, ) -> EnvelopeResult<Option<CategoryGroup>>

Get a group by ID

pub fn get_group_by_name( &self, name: &str, ) -> EnvelopeResult<Option<CategoryGroup>>

Get a group by name (case-insensitive)

pub fn find_group( &self, identifier: &str, ) -> EnvelopeResult<Option<CategoryGroup>>

Find a group by name or ID string

pub fn list_groups(&self) -> EnvelopeResult<Vec<CategoryGroup>>

List all groups

pub fn list_groups_with_categories( &self, ) -> EnvelopeResult<Vec<CategoryGroupWithCategories>>

List all groups with their categories

pub fn update_group( &self, id: CategoryGroupId, name: Option<&str>, ) -> EnvelopeResult<CategoryGroup>

Update a group’s name

pub fn delete_group( &self, id: CategoryGroupId, force_delete_categories: bool, ) -> EnvelopeResult<()>

Delete a group

If the group has categories, they must be moved or deleted first unless force_delete_categories is true.

Automatically creates a backup before deletion if one hasn’t been created recently.

pub fn reorder_groups(&self, order: &[CategoryGroupId]) -> EnvelopeResult<()>

Reorder groups

pub fn create_category( &self, name: &str, group_id: CategoryGroupId, ) -> EnvelopeResult<Category>

Create a new category in a group

pub fn get_category(&self, id: CategoryId) -> EnvelopeResult<Option<Category>>

Get a category by ID

pub fn get_category_by_name( &self, name: &str, ) -> EnvelopeResult<Option<Category>>

Get a category by name (case-insensitive)

pub fn find_category( &self, identifier: &str, ) -> EnvelopeResult<Option<Category>>

Find a category by name or ID string

pub fn list_categories(&self) -> EnvelopeResult<Vec<Category>>

List all categories

pub fn list_categories_in_group( &self, group_id: CategoryGroupId, ) -> EnvelopeResult<Vec<Category>>

List categories in a group

pub fn update_category( &self, id: CategoryId, name: Option<&str>, goal: Option<i64>, clear_goal: bool, ) -> EnvelopeResult<Category>

Update a category

pub fn move_category( &self, id: CategoryId, new_group_id: CategoryGroupId, ) -> EnvelopeResult<Category>

Move a category to a different group

pub fn delete_category(&self, id: CategoryId) -> EnvelopeResult<()>

Delete a category

Automatically creates a backup before deletion if one hasn’t been created recently.

pub fn reorder_categories( &self, group_id: CategoryGroupId, order: &[CategoryId], ) -> EnvelopeResult<()>

Reorder categories within a group