TransactionService

Struct TransactionService 

pub struct TransactionService<'a> { /* private fields */ }
Service for transaction management

Implementations

Source

impl<'a> TransactionService<'a>

pub fn new(storage: &'a Storage) -> Self

Create a new transaction service

pub fn create( &self, input: CreateTransactionInput, ) -> EnvelopeResult<Transaction>

Create a new transaction

pub fn get(&self, id: TransactionId) -> EnvelopeResult<Option<Transaction>>

Get a transaction by ID

pub fn find(&self, identifier: &str) -> EnvelopeResult<Option<Transaction>>

Find a transaction by ID string

pub fn list( &self, filter: TransactionFilter, ) -> EnvelopeResult<Vec<Transaction>>

List all transactions with optional filtering

pub fn list_for_account( &self, account_id: AccountId, ) -> EnvelopeResult<Vec<Transaction>>

Get transactions for an account

pub fn list_for_category( &self, category_id: CategoryId, ) -> EnvelopeResult<Vec<Transaction>>

Get transactions for a category

pub fn update( &self, id: TransactionId, date: Option<NaiveDate>, amount: Option<Money>, payee_name: Option<String>, category_id: Option<Option<CategoryId>>, memo: Option<String>, ) -> EnvelopeResult<Transaction>

Update a transaction

pub fn delete(&self, id: TransactionId) -> EnvelopeResult<Transaction>

Delete a transaction

pub fn set_status( &self, id: TransactionId, status: TransactionStatus, ) -> EnvelopeResult<Transaction>

Set the status of a transaction

pub fn clear(&self, id: TransactionId) -> EnvelopeResult<Transaction>

Clear a transaction (mark as cleared)

pub fn unclear(&self, id: TransactionId) -> EnvelopeResult<Transaction>

Unclear a transaction (mark as pending)

pub fn unlock(&self, id: TransactionId) -> EnvelopeResult<Transaction>

Unlock a reconciled transaction for editing

This is a potentially dangerous operation - it allows editing a transaction that has already been reconciled with a bank statement. Use with caution.

pub fn add_split( &self, id: TransactionId, category_id: CategoryId, amount: Money, memo: Option<String>, ) -> EnvelopeResult<Transaction>

Add a split to a transaction

Note: This validates that splits total equals the transaction amount. If you need to add multiple splits, use set_splits instead to avoid intermediate validation failures.

pub fn set_splits( &self, id: TransactionId, splits: Vec<Split>, ) -> EnvelopeResult<Transaction>

Set all splits for a transaction at once

This replaces any existing splits with the new ones. The splits must sum to the transaction amount.

pub fn clear_splits(&self, id: TransactionId) -> EnvelopeResult<Transaction>

Clear all splits from a transaction

pub fn learn_from_transaction(&self, txn: &Transaction) -> EnvelopeResult<()>

Learn from a transaction - update payee’s category frequency

pub fn suggest_category( &self, payee_name: &str, ) -> EnvelopeResult<Option<CategoryId>>

Get suggested category for a payee name

pub fn count(&self) -> EnvelopeResult<usize>

Count transactions

pub fn get_uncleared( &self, account_id: AccountId, ) -> EnvelopeResult<Vec<Transaction>>

Get uncleared transactions for an account

pub fn get_cleared( &self, account_id: AccountId, ) -> EnvelopeResult<Vec<Transaction>>

Get cleared (but not reconciled) transactions for an account