Event handler for the TUI
Routes keyboard and mouse events to the appropriate handlers based on the current application state.
Functions
- handle_
event - Handle an incoming event
Event handler for the TUI
Routes keyboard and mouse events to the appropriate handlers based on the current application state.