pub struct AuditEntry {
pub timestamp: DateTime<Utc>,
pub operation: Operation,
pub entity_type: EntityType,
pub entity_id: String,
pub entity_name: Option<String>,
pub before: Option<Value>,
pub after: Option<Value>,
pub diff_summary: Option<String>,
}Expand description
A single audit log entry
Records a single operation on an entity with optional before/after values for tracking changes.
Fields
timestamp: DateTime<Utc>When the operation occurred (UTC)
operation: OperationType of operation performed
entity_type: EntityTypeType of entity affected
entity_id: StringID of the affected entity
entity_name: Option<String>Human-readable description of the entity (e.g., account name)
before: Option<Value>JSON representation of the entity before the operation (for updates/deletes)
after: Option<Value>JSON representation of the entity after the operation (for creates/updates)
diff_summary: Option<String>Human-readable diff summary
Implementations
Sourceimpl AuditEntry
impl AuditEntry
Sourcepub fn create<T: Serialize>(
entity_type: EntityType,
entity_id: impl Into<String>,
entity_name: Option<String>,
entity: &T,
) -> Self
pub fn create<T: Serialize>( entity_type: EntityType, entity_id: impl Into<String>, entity_name: Option<String>, entity: &T, ) -> Self
Create a new audit entry for a create operation
Sourcepub fn update<T: Serialize>(
entity_type: EntityType,
entity_id: impl Into<String>,
entity_name: Option<String>,
before: &T,
after: &T,
diff_summary: Option<String>,
) -> Self
pub fn update<T: Serialize>( entity_type: EntityType, entity_id: impl Into<String>, entity_name: Option<String>, before: &T, after: &T, diff_summary: Option<String>, ) -> Self
Create a new audit entry for an update operation
Sourcepub fn delete<T: Serialize>(
entity_type: EntityType,
entity_id: impl Into<String>,
entity_name: Option<String>,
entity: &T,
) -> Self
pub fn delete<T: Serialize>( entity_type: EntityType, entity_id: impl Into<String>, entity_name: Option<String>, entity: &T, ) -> Self
Create a new audit entry for a delete operation
Sourcepub fn format_human_readable(&self) -> String
pub fn format_human_readable(&self) -> String
Format the entry for human-readable output