Module secure_memory

Module secure_memory 

Secure memory handling for sensitive data

Provides types that securely zero memory on drop to prevent sensitive data from lingering in memory.

Structs

SecureBytes
A byte vector that zeros its contents on drop
SecureString
A string type that zeros its contents on drop