Account display formatting
Formats accounts for terminal output in table and detail views.
Functions
- format_
account_ details - Format a single account’s details
- format_
account_ list - Format a list of accounts with balances as a table
- format_
account_ list_ simple - Format a simple account list (name and type only)