File I/O utilities with atomic writes
Provides safe file operations that won’t corrupt data on failure.
Functions
- json_
file_ valid - Check if a JSON file exists and is valid
- read_
json - Read JSON from a file, returning a default value if file doesn’t exist
- read_
json_ required - Read JSON from a file, returning an error if file doesn’t exist
- write_
json_ atomic - Write JSON to a file atomically (write to temp, then rename)