Account entry dialog
Modal dialog for adding new accounts with form fields, tab navigation, validation, and save/cancel functionality.
Structs
- Account
Form State - State for the account form dialog
Enums
- Account
Field - Which field is currently focused in the account form
Functions
- handle_
key - Handle key input for the account dialog
- render
- Render the account dialog